package org.cpan.knth;

public abstract class TAPGeneratorException extends RuntimeException
{
	private static final long serialVersionUID = -222974507428661138L;
	
	public TAPGeneratorException(String s)
	{
		super(s);
	}
}
